==> qtjambi-debuginfo-windows-x64-6.5.4.jar: sources/QtJambiGui/QPointerEvent_shell.h <==
#ifndef QPOINTEREVENT_SHELL_H
#define QPOINTEREVENT_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtGui/qevent.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qcoreevent.h>
#include <QtCore/qobject.h>
#include <QtGui/qeventpoint.h>
#include <QtGui/qinputdevice.h>
#include <QtGui/qpointingdevice.h>
#include <QtJambi/RegistryAPI>


class QPointerEvent_shell : public QPointerEvent, public QtJambiShellInterface
{
public:
    QPointerEvent_shell(QEvent::Type type0, const QPointingDevice* dev1, Qt::KeyboardModifiers modifiers2 = Qt::NoModifier, const QList<QEventPoint>& points3 = {});
    QPointerEvent_shell(const QPointerEvent& arg__1);
    ~QPointerEvent_shell() override;

    QPointerEvent* clone() const override;
    bool isBeginEvent() const override;
    bool isEndEvent() const override;
    bool isUpdateEvent() const override;
    void setAccepted(bool accepted0) override;
    void setTimestamp(quint64 timestamp0) override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QPointerEvent_access : public QPointerEvent
{
    void __qt_assign_cref_QPointerEvent(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID other0);
    jobject __qt_clone(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_isBeginEvent(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_isEndEvent(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_isUpdateEvent(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_setAccepted_bool(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jboolean accepted0);
    void __qt_setTimestamp_quint64(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jlong timestamp0);
};

#endif // QPOINTEREVENT_SHELL_H

==> qtjambi-debuginfo-windows-x64-6.6.3.jar: sources/QtJambiGui/QPointerEvent_shell.h <==
#ifndef QPOINTEREVENT_SHELL_H
#define QPOINTEREVENT_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtGui/qevent.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qcoreevent.h>
#include <QtCore/qobject.h>
#include <QtGui/qeventpoint.h>
#include <QtGui/qinputdevice.h>
#include <QtGui/qpointingdevice.h>
#include <QtJambi/RegistryAPI>


class QPointerEvent_shell : public QPointerEvent, public QtJambiShellInterface
{
public:
    QPointerEvent_shell(QEvent::Type type0, const QPointingDevice* dev1, Qt::KeyboardModifiers modifiers2 = Qt::NoModifier, const QList<QEventPoint>& points3 = {});
    QPointerEvent_shell(const QPointerEvent& arg__1);
    ~QPointerEvent_shell() override;

    QPointerEvent* clone() const override;
    bool isBeginEvent() const override;
    bool isEndEvent() const override;
    bool isUpdateEvent() const override;
    void setAccepted(bool accepted0) override;
    void setTimestamp(quint64 timestamp0) override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QPointerEvent_access : public QPointerEvent
{
    void __qt_assign_cref_QPointerEvent(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID other0);
    jobject __qt_clone_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_isBeginEvent_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_isEndEvent_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_isUpdateEvent_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_setAccepted_bool(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jboolean accepted0);
    void __qt_setTimestamp_quint64(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jlong timestamp0);
};

#endif // QPOINTEREVENT_SHELL_H
